$set 10 #Windowmenu

$ #SendTo
#   ...
$ #SendGroupTo
#   ...
$ #Shade
#   
$ #Iconify
#    
$ #Maximize
# 
$ #Raise
#   
$ #Lower
#   
$ #Stick
# 
$ #KillClient
#   
$ #Close
# 
$ #Tab
#  
